import { Injectable } from '@nestjs/common'
import { CreateGeolocationDto } from './dto/create-geolocation.dto'
import { PrismaService } from 'src/prisma/prisma.service'
import { Geolocation, User } from '@prisma/client'

@Injectable()
export class GeolocationsService {
  constructor(private prisma: PrismaService) { }

  async create(authenticatedUser: User, createGeolocationDto: CreateGeolocationDto): Promise<Geolocation> {
    const data = { ...createGeolocationDto, userId: authenticatedUser.id }
    return await this.prisma.geolocation.create({ data: data })
  }

  async findAll(): Promise<Geolocation[]> {
    return await this.prisma.geolocation.findMany()
  }

  async findOne(id: number): Promise<Geolocation> {
    return await this.prisma.geolocation.findUnique({ where: { id } })
  }


  async remove(id: number): Promise<Geolocation> {
    return await this.prisma.geolocation.delete({ where: { id } })
  }
}
