import { Injectable } from '@nestjs/common'
import { User } from '@prisma/client'
import { PrismaService } from 'src/prisma/prisma.service'
import * as bcrypt from 'bcrypt'
import { UpdatePasswordDto } from './dto/user_password.dto'

@Injectable()
export class UsersService {
  constructor(private prisma: PrismaService) {}

  async findAll() {
    return await this.prisma.user.findMany()
  }

  async findOne(id: number) {
    return await this.prisma.user.findUnique({ where: { id } })
  }

  async updatePassword(user: User, { password }: UpdatePasswordDto) {
    const hashedPassword = await bcrypt.hash(password, 10)
    await this.prisma.user.update({
      where: { id: user.id },
      data: { password: hashedPassword }
    })
  }
}
